Struct RegistryState
pub struct RegistryState { /* private fields */ }wayland and Linux only.Expand description
State object associated with the registry handling for smithay’s client toolkit.
This object provides utilities to cache bound globals that are needed by multiple modules.
Implementations
impl RegistryState
impl RegistryState
pub fn new(global_list: &GlobalList) -> RegistryState
pub fn new(global_list: &GlobalList) -> RegistryState
Creates a new registry handle.
This type may be used to bind globals as they are advertised.
pub fn registry(&self) -> &WlRegistry
pub fn globals(&self) -> impl Iterator<Item = &Global>
pub fn globals(&self) -> impl Iterator<Item = &Global>
Returns an iterator over all globals.
This list may change if the compositor adds or removes globals after initial enumeration.
No guarantees are provided about the ordering of the globals in this iterator.
pub fn globals_by_interface<'a>(
&'a self,
interface: &'a str,
) -> impl Iterator<Item = &'a Global> + 'a
pub fn globals_by_interface<'a>( &'a self, interface: &'a str, ) -> impl Iterator<Item = &'a Global> + 'a
Returns an iterator over all globals implementing the given interface.
This may be more efficient than searching Self::globals.
pub fn bind_one<I, D, U>(
&self,
qh: &QueueHandle<D>,
version: RangeInclusive<u32>,
udata: U,
) -> Result<I, BindError>
pub fn bind_one<I, D, U>( &self, qh: &QueueHandle<D>, version: RangeInclusive<u32>, udata: U, ) -> Result<I, BindError>
Binds a global, returning a new object associated with the global.
This should not be used to bind globals that have multiple instances such as wl_output;
use Self::bind_all instead.
pub fn bind_specific<I, D, U>(
&self,
qh: &QueueHandle<D>,
name: u32,
version: RangeInclusive<u32>,
udata: U,
) -> Result<I, BindError>
pub fn bind_specific<I, D, U>( &self, qh: &QueueHandle<D>, name: u32, version: RangeInclusive<u32>, udata: U, ) -> Result<I, BindError>
Binds a global, returning a new object associated with the global.
This binds a specific object by its name as provided by the RegistryHandler::new_global callback.